@@ -21,7 +21,7 @@ from playwright.sync_api import TimeoutError as PlaywrightTimeoutError
 from functools import partial
 
 from .fun_win import find_software_install_path
-from .fun_base import log, hostname, send_exception
+from .fun_base import log, hostname, send_exception, NetWorkIdleTimeout
 from .fun_file import check_progress_json_ex, get_progress_json_ex, done_progress_json_ex, write_dict_to_file_ex
 
 class ZiniaoClient:
@@ -260,7 +260,6 @@ class ZiniaoBrowser:
         page.goto(launcher_page)
         page.wait_for_load_state('load')
 
-        # 业务逻辑
         run_func(page, store_username, store_name, task_key)
 
         # 标记完成
@@ -332,7 +331,14 @@ class ZiniaoTaskManager:
                         ip_usable = self.browser.open_ip_check(browser_context, ip_check_url)
                         if ip_usable:
                             print("ip检测通过，打开店铺平台主页")
-                            self.browser.open_launcher_page(browser_context, ret_json.get("launcherPage"), store_username, store_name, run_func, task_key)
+                            # 业务逻辑
+                            try:
+                                self.browser.open_launcher_page(browser_context, ret_json.get("launcherPage"), store_username, store_name, run_func, task_key)
+                            except NetWorkIdleTimeout:
+                                log('捕获到自定义错误: NetWorkIdleTimeout')
+                                self.browser.close_store(store_id)
+                                pass
+
                         else:
                             print("ip检测不通过，请检查")
                     except:
@@ -412,7 +418,7 @@ class ZiniaoRunner:
             raise RuntimeError("店铺列表为空")
 
         # 多线程并发执行任务
-        max_threads = 5 if (hostname().lower() == 'krrpa') else 3
+        max_threads = 1 if (hostname().lower() == 'krrpa') else 3
         log(f'当前启用线程数: {max_threads}')
         self.task_manager.run_with_thread_pool(browser_list, max_threads, run, task_key, just_store_username, is_skip_store)
 
